==> tv_8.2201-2509122314.zip: dyn/ru/bitel/bgbilling/modules/tv/dyn/cti/tve/ws/billing/QuerySummByService.java <==

package ru.bitel.bgbilling.modules.tv.dyn.cti.tve.ws.billing;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for querySummByService complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="querySummByService">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="arg0" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
 *         &lt;element name="arg1" type="{http://ws.external.push.adapter.billing.integration.iptv.oss.cti.ru/}serviceSpecification" minOccurs="0"/>
 *         &lt;element name="arg2" type="{http://ws.external.push.adapter.billing.integration.iptv.oss.cti.ru/}timeFrame" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "querySummByService", propOrder = {
    "arg0",
    "arg1",
    "arg2"
})
public class QuerySummByService {

    protected String arg0;
    protected ServiceSpecification arg1;
    protected TimeFrame arg2;

    /**
     * Gets the value of the arg0 property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getArg0() {
        return arg0;
    }

    /**
     * Sets the value of the arg0 property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setArg0(String value) {
        this.arg0 = value;
    }

    /**
     * Gets the value of the arg1 property.
     * 
     * @return
     *     possible object is
     *     {@link ServiceSpecification }
     *     
     */
    public ServiceSpecification getArg1() {
        return arg1;
    }

    /**
     * Sets the value of the arg1 property.
     * 
     * @param value
     *     allowed object is
     *     {@link ServiceSpecification }
     *     
     */
    public void setArg1(ServiceSpecification value) {
        this.arg1 = value;
    }

    /**
     * Gets the value of the arg2 property.
     * 
     * @return
     *     possible object is
     *     {@link TimeFrame }
     *     
     */
    public TimeFrame getArg2() {
        return arg2;
    }

    /**
     * Sets the value of the arg2 property.
     * 
     * @param value
     *     allowed object is
     *     {@link TimeFrame }
     *     
     */
    public void setArg2(TimeFrame value) {
        this.arg2 = value;
    }

}

==> tv_10.2504-2509150239.zip: dyn/ru/bitel/bgbilling/modules/tv/dyn/cti/tve/ws/billing/QuerySummByService.java <==

package ru.bitel.bgbilling.modules.tv.dyn.cti.tve.ws.billing;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <p>Java class for querySummByService complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="querySummByService">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="arg0" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
 *         &lt;element name="arg1" type="{http://ws.external.push.adapter.billing.integration.iptv.oss.cti.ru/}serviceSpecification" minOccurs="0"/>
 *         &lt;element name="arg2" type="{http://ws.external.push.adapter.billing.integration.iptv.oss.cti.ru/}timeFrame" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "querySummByService", propOrder = {
    "arg0",
    "arg1",
    "arg2"
})
public class QuerySummByService {

    protected String arg0;
    protected ServiceSpecification arg1;
    protected TimeFrame arg2;

    /**
     * Gets the value of the arg0 property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getArg0() {
        return arg0;
    }

    /**
     * Sets the value of the arg0 property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setArg0(String value) {
        this.arg0 = value;
    }

    /**
     * Gets the value of the arg1 property.
     * 
     * @return
     *     possible object is
     *     {@link ServiceSpecification }
     *     
     */
    public ServiceSpecification getArg1() {
        return arg1;
    }

    /**
     * Sets the value of the arg1 property.
     * 
     * @param value
     *     allowed object is
     *     {@link ServiceSpecification }
     *     
     */
    public void setArg1(ServiceSpecification value) {
        this.arg1 = value;
    }

    /**
     * Gets the value of the arg2 property.
     * 
     * @return
     *     possible object is
     *     {@link TimeFrame }
     *     
     */
    public TimeFrame getArg2() {
        return arg2;
    }

    /**
     * Sets the value of the arg2 property.
     * 
     * @param value
     *     allowed object is
     *     {@link TimeFrame }
     *     
     */
    public void setArg2(TimeFrame value) {
        this.arg2 = value;
    }

}
